<?php

namespace Crm\Agent\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\Agent\Events\AgentAction as AgentActionEvent;
use Crm\Agent\Notifications\AgentAction as AgentActionNotification;
use Litepie\Actions\Concerns\AsAction;

class AgentAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the AgentActionEvent.
     *
     * @param   AgentActionEvent  $event
     * @return mixed
     */
    public function handle(AgentActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $agent.
     *
     * @param   AgentActionEvent  $event
     * @return void
     */
    public function create(AgentActionEvent $event)
    {
        $client = $event->agent->client;
        Notification::send($client, new AgentActionNotification($event));
    }

    /**
     * Handle the AgentActionEvent as a listener.
     *
     * @param   AgentActionEvent  $event
     * @return mixed
     */
    public function asListener(AgentActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   AgentActionEvent  $event
     * @return bool
     */
    private function isAllowed(AgentActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
