<?php

namespace Crm\Agent\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\Agent\Events\AgentWorkflow as AgentWorkflowEvent;
use Crm\Agent\Notifications\AgentWorkflow as AgentWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class AgentWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(AgentWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $agent is submitted.
     *
     * @param AgentWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(AgentWorkflowEvent $event)
    {
        $client = $event->agent->client;
        Notification::send($client, new AgentWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $agent is published.
     *
     * @param AgentWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(AgentWorkflowEvent $event)
    {
        $client = $event->agent->client;
        Notification::send($client, new AgentWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $agent is approved.
     *
     * @param AgentWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(AgentWorkflowEvent $event)
    {
        $client = $event->agent->client;
        Notification::send($client, new AgentWorkflowNotification($event));
    }

    /**
     * Handles the $agent workflow event as a listener.
     *
     * @param AgentWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(AgentWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
