<?php

namespace Crm\Agent\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\Agent\Models\Agent;

class AgentPolicy
{


    /**
     * Determine if the given user can view the agent.
     *
     * @param Authenticatable $user
     * @param Agent $agent
     *
     * @return bool
     */
    public function view(Authenticatable $user, Agent $agent)
    {
        if ($authUser->canDo('agent.agent.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $agent->is_owner;
    }

    /**
     * Determine if the given user can create a agent.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('agent.agent.create');
    }

    /**
     * Determine if the given user can update the given agent.
     *
     * @param Authenticatable $user
     * @param Agent $agent
     *
     * @return bool
     */
    public function update(Authenticatable $user, Agent $agent)
    {
        if ($user->canDo('agent.agent.edit') && $user->isAdmin()) {
            return true;
        }

        return $agent->is_owner;
    }

    /**
     * Determine if the given user can delete the given agent.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Agent $agent)
    {
        return $agent->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
